=======
History
=======

0.1.0 (2023-05-08)
------------------

* First release on PyPI.

1. Automated Data Processing (+ PCA)
2. Dimensionality Reduction through t-SNE
3. Clustering with KMeans
4. Post Analysis utilities through plots and stats
